@@ -32,10 +32,12 @@ Import all parts from awsenergylabelercli here
    http://google.github.io/styleguide/pyguide.html
 """
 from ._version import __version__
-from .awsenergylabelercli import (get_arguments,
-                                  setup_logging,
-                                  get_landing_zone_reporting_data,
-                                  get_account_reporting_data)
+from .awsenergylabelercli import (calculate_file_hash,
+                                  get_account_reporting_data,
+                                  get_arguments,
+                                  get_parser,
+                                  get_zone_reporting_data,
+                                  setup_logging)
 
 __author__ = '''Theodoor Scholte <tscholte@schubergphilis.com>'''
 __docformat__ = '''google'''
@@ -49,7 +51,9 @@ __status__ = '''Development'''  # "Prototype", "Development", "Production".
 # This is to 'use' the module(s), so lint doesn't complain
 assert __version__
 
-assert get_arguments
-assert setup_logging
-assert get_landing_zone_reporting_data
+assert calculate_file_hash
 assert get_account_reporting_data
+assert get_arguments
+assert get_parser
+assert get_zone_reporting_data
+assert setup_logging
